@@ -32,12 +32,6 @@ static gboolean no_interactive = FALSE;
 /* declaration of debug handler */
 static void gdata_test_debug_handler (const gchar *log_domain, GLogLevelFlags log_level, const gchar *message, gpointer user_data);
 
-/* declaration of printerr handler */
-static void gdata_test_assert_handler (const gchar *message);
-
-/* global list of debugging messages */
-static GSList *message_list = NULL;
-
 /* Directory to output network trace files to, if trace output is enabled. (NULL otherwise.) */
 static GFile *trace_dir = NULL;
 
@@ -117,10 +111,7 @@ gdata_test_init (int argc, char **argv)
 	g_test_bug_base ("http://bugzilla.gnome.org/show_bug.cgi?id=");
 
 	/* Set handler of debug information */
-	g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, (GLogFunc) gdata_test_debug_handler, message_list);
-
-	/* Set handler for printerr */
-	g_set_printerr_handler ((GPrintFunc) gdata_test_assert_handler);
+	g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, (GLogFunc) gdata_test_debug_handler, NULL);
 
 	/* Enable full debugging. These options are seriously unsafe, but we don't care for test cases. */
 	g_setenv ("LIBGDATA_DEBUG", "4" /* GDATA_LOG_FULL_UNREDACTED */, FALSE);
@@ -873,49 +864,35 @@ gdata_tear_down_async_test_data (GDataAsyncTestData *async_data, gconstpointer t
 	g_main_loop_unref (async_data->main_loop);
 }
 
-void
-gdata_test_debug_output (void)
+static void
+output_log_message (const gchar *message)
 {
-	if (message_list == NULL) {
-		/* No debugging messages */
-		return;
+	if (strlen (message) > 2 && message[2] == '<') {
+		/* As debug string starts with direction indicator and space, t.i. "< ", */
+		/* we need access string starting from third character and see if it's   */
+		/* looks like xml - t.i. it starts with '<' */
+		xmlChar *xml_buff;
+		int buffer_size;
+		xmlDocPtr xml_doc;
+		/* we need to cut to the begining of XML string */
+		message = message + 2;
+		/* create xml document and dump it to string buffer */
+		xml_doc = xmlParseDoc ((const xmlChar*) message);
+		xmlDocDumpFormatMemory (xml_doc, &xml_buff, &buffer_size, 1);
+		/* print out structured xml - if it's not xml, it will get error in output */
+		printf("%s", (gchar*) xml_buff);
+		/* free xml structs */
+		xmlFree (xml_buff);
+		xmlFreeDoc (xml_doc);
+	} else {
+		printf ("%s\n", (gchar*) message);
 	}
-	do {
-		gchar *message = (gchar*) message_list->data;
-		if (message != NULL) {
-			if (strlen (message) > 2 && message[2] == '<') {
-				/* As debug string starts with direction indicator and space, t.i. "< ", */
-				/* we need access string starting from third character and see if it's   */
-				/* looks like xml - t.i. it starts with '<' */
-				xmlChar *xml_buff;
-				int buffer_size;
-				xmlDocPtr xml_doc;
-				/* we need to cut to the begining of XML string */
-				message = message + 2;
-				/* create xml document and dump it to string buffer */
-				xml_doc = xmlParseDoc ((const xmlChar*) message);
-				xmlDocDumpFormatMemory (xml_doc, &xml_buff, &buffer_size, 1);
-				/* print out structured xml - if it's not xml, it will get error in output */
-				printf("%s", (gchar*) xml_buff);
-				/* free xml structs */
-				xmlFree (xml_buff);
-				xmlFreeDoc (xml_doc);
-			} else {
-				printf ("%s\n", (gchar*) message);
-			}
-			/* free gchar */
-			g_free ((gpointer) message_list->data);
-		}
-		/* free GSList node */
-		message_list = g_slist_delete_link (message_list, message_list);
-	} while (message_list != NULL);
 }
 
 static void
 gdata_test_debug_handler (const gchar *log_domain, GLogLevelFlags log_level, const gchar *message, gpointer user_data)
 {
-	/* storing debugging messages in GSList for displaying them in case of error */
-	message_list = g_slist_append (message_list, g_strdup (message));
+	output_log_message (message);
 
 	/* Log to the trace file. */
 	if (message != NULL && (*message == '<' || *message == '>' || *message == ' ') && *(message + 1) == ' ') {
@@ -923,13 +900,6 @@ gdata_test_debug_handler (const gchar *log_domain, GLogLevelFlags log_level, con
 	}
 }
 
-static void
-gdata_test_assert_handler (const gchar *message)
-{
-	gdata_test_debug_output ();
-	printf ("%s", (gchar*) message);
-}
-
 /**
  * gdata_test_set_https_port:
  * @server: a #UhmServer
@@ -960,7 +930,10 @@ gdata_test_set_https_port (UhmServer *server)
 void
 gdata_test_mock_server_start_trace (UhmServer *server, const gchar *trace_filename)
 {
-	uhm_server_start_trace (server, trace_filename, NULL);
+	GError *child_error = NULL;
+
+	uhm_server_start_trace (server, trace_filename, &child_error);
+	g_assert_no_error (child_error);
 	gdata_test_set_https_port (server);
 }
 
@@ -1011,3 +984,32 @@ gdata_test_mock_server_handle_message_timeout (UhmServer *server, SoupMessage *m
 
 	return TRUE;
 }
+
+/**
+ * gdata_test_query_user_for_verifier:
+ * @authentication_uri: authentication URI to present
+ *
+ * Given an authentication URI, prompt the user to go to that URI, grant access
+ * to the test application and enter the resulting verifier. This is to be used
+ * with interactive OAuth authorisation requests.
+ *
+ * Returns: (transfer full): verifier from the web page
+ */
+gchar *
+gdata_test_query_user_for_verifier (const gchar *authentication_uri)
+{
+	char verifier[100];
+
+	/* Wait for the user to retrieve and enter the verifier */
+	g_print ("Please navigate to the following URI and grant access: %s\n", authentication_uri);
+	g_print ("Enter verifier (EOF to skip test): ");
+	if (scanf ("%100s", verifier) != 1) {
+		/* Skip the test */
+		g_test_message ("Skipping test on user request.");
+		return NULL;
+	}
+
+	g_test_message ("Proceeding with user-provided verifier “%s”.", verifier);
+
+	return g_strdup (verifier);
+}
